@@ -30,10 +30,14 @@ public interface TestConf {
   @BeforeEach
   default void clear() {
     conf.clear();
+    conf.setIfUnset("fs.defaultFS", "file:///");
+    conf.setIfUnset("fs.file.impl.disable.cache", "true");
   }
 
   private static Configuration getNewConf() {
     Configuration conf = new Configuration();
+    conf.setIfUnset("fs.defaultFS", "file:///");
+    conf.setIfUnset("fs.file.impl.disable.cache", "true");
     return conf;
   }
 }
